Embedding a Listing Search
==========================


Activate the Listing Search
---------------------------

At first, open the **Actions**-menu and select **Activate Listing Search**:

.. image:: ../_images/activate_listing_search.png

When the **Listing Search** was activated, you will see a status message:

.. image:: ../_images/activate_listing_search_done.png

To configure the **Listing Search** click on the new link **Configure Listing Search**:

.. image:: ../_images/configure_listing_search.png

Once all search criterias are entered click the **Save** button.

To de-activate the **Listing Search** again, open the **Actions**-menu and select **Deactivate Listing Search**:

.. image:: ../_images/deactivate_listing_search.png

When the **Listing Search** was deactivated, you will see a status message:

.. image:: ../_images/deactivate_listing_search_done.png


Add a Quick Search Portlet
--------------------------
